#define LAZINESS Strict

-- | A persistent store for values of arbitrary types.
--
-- The 'Vault' type in this module is strict in both keys and values.
#include "IO.h"
